@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.6
+# Version   : 0.3.7
 
 from operator import contains
 import  numpy                   as      np
@@ -491,7 +491,8 @@ class AFM:
 
     def plot_raw(
         self,
-        curve_number = 1
+        curve_number = 1,
+        return_fig = False
     ):
         '''
         Function to plot individual, unprocessed force curves. Curve number to
@@ -506,6 +507,10 @@ class AFM:
                 xaxis_title_text='Piezo position (nm)',
             )
             fig.show()
+            
+            if return_fig == True:
+                return fig
+
 
         else:
             fig = go.Figure()
@@ -516,6 +521,9 @@ class AFM:
                 xaxis_title_text='Piezo position (m)',
             )
             fig.show()
+            
+            if return_fig == True:
+                return fig
 
     def baseline(
         self,
@@ -677,7 +685,8 @@ class AFM:
 
     def plot_adjusted(
         self,
-        curve_number = 1
+        curve_number = 1,
+        return_fig = False
     ):
         '''
         Function to plot individual, processed force curves. Curve number to
@@ -691,8 +700,12 @@ class AFM:
             xaxis_title_text='Distance, z (nm)',
         )
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
-    def plot_curves(self):
+    def plot_curves(self,
+        return_fig = False):
         '''
         Function to plot all processed force curves
         '''
@@ -749,6 +762,9 @@ class AFM:
         )
 
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def delete_curve(self,*args):
         '''
@@ -899,7 +915,8 @@ class AFM:
 
     def calc_adhesion(
         self,
-        plot_hist = False
+        plot_hist = False,
+        return_fig = False
     ):
         '''
         Funciton to calculate the adhesion value for each curve by finding the minimum
@@ -924,6 +941,9 @@ class AFM:
                 yaxis_title_text='Count',
             )
             fig.show()
+            
+            if return_fig == True:
+                return fig
 
         print('')
         try:
@@ -936,7 +956,8 @@ class AFM:
 
     def overlay_adhesion_hist(
         self,
-        *all_adhesion
+        *all_adhesion,
+        return_fig = False
     ):
         '''
         Funciton to plot a histogram comparing adhesion values for multiple experiments.
@@ -957,10 +978,14 @@ class AFM:
             )
         fig.update_traces(opacity=0.75)
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def overlay_adhesion_box(
         self,
-        *all_adhesion
+        *all_adhesion,
+        return_fig = False
     ):
         '''
         Funciton to produce a box plot comparing adhesion values for multiple experiments.
@@ -979,10 +1004,14 @@ class AFM:
             )
             
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def overlay_adhesion_violin(
         self,
-        *all_adhesion
+        *all_adhesion,
+        return_fig = False
     ):
         '''
         Funciton to produce a violin plot comparing adhesion values for multiple experiments.
@@ -1001,10 +1030,14 @@ class AFM:
             )
             
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def overlay_adhesion_bar(
         self,
-        *all_adhesion
+        *all_adhesion,
+        return_fig = False
     ):
         '''
         Funciton to produce a bar chart comparing adhesion values for multiple experiments.
@@ -1033,12 +1066,16 @@ class AFM:
             )
             
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def calc_modulus(
         self,
         poisson_ratio = 0.5,
         indenter_radius = 10 * 1e-9,
         plot_hist = False,
+        return_fig = False,
         soft_indenter = False,
         indenter_poisson_ratio = 0.5,
         indenter_modulus = 1000
@@ -1080,6 +1117,9 @@ class AFM:
                 yaxis_title_text='Count',
             )
             fig.show()
+            
+        if return_fig == True:
+            return fig
 
         print('')
         try:
@@ -1095,6 +1135,7 @@ class AFM:
         poisson_ratio = 0.5,
         opening_angle = 35,
         plot_hist = False,
+        return_fig = False
     ):
         '''
         Funciton to calculate the modulus value for each curve using the Sneddon model.
@@ -1127,6 +1168,9 @@ class AFM:
                 yaxis_title_text='Count',
             )
             fig.show()
+            
+        if return_fig == True:
+            return fig
 
         print('')
         try:
@@ -1142,6 +1186,7 @@ class AFM:
         poisson_ratio = 0.5,
         face_angle = 35,
         plot_hist = False,
+        return_fig = False
     ):
         '''
         Funciton to calculate the modulus value for each curve using the four sided pyramid model.
@@ -1174,6 +1219,9 @@ class AFM:
                 yaxis_title_text='Count',
             )
             fig.show()
+            
+        if return_fig == True:
+            return fig
 
         print('')
         try:
@@ -1186,7 +1234,8 @@ class AFM:
 
     def overlay_modulus_hist(
         self,
-        *all_modulus
+        *all_modulus,
+        return_fig = False
     ):
         '''
         Funciton to plot a histogram comparing modulus values for multiple experiments.
@@ -1207,10 +1256,14 @@ class AFM:
             )
         fig.update_traces(opacity=0.75)
         fig.show()
+            
+        if return_fig == True:
+            return fig
     
     def overlay_modulus_box(
         self,
-        *all_modulus
+        *all_modulus,
+        return_fig = False
     ):
         '''
         Funciton to produce a box plot comparing modulus values for multiple experiments.
@@ -1229,10 +1282,14 @@ class AFM:
             )
             
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def overlay_modulus_violin(
         self,
-        *all_modulus
+        *all_modulus,
+        return_fig = False
     ):
         '''
         Funciton to produce a violin plot comparing modulus values for multiple experiments.
@@ -1251,10 +1308,14 @@ class AFM:
             )
             
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def overlay_modulus_bar(
         self,
-        *all_modulus
+        *all_modulus,
+        return_fig = False
     ):
         '''
         Funciton to produce a bar chart comparing modulus values for multiple experiments.
@@ -1283,7 +1344,11 @@ class AFM:
 
         fig.show()
 
-    def plot_adhesion_modulus(self):
+        if return_fig == True:
+            return fig
+
+    def plot_adhesion_modulus(self,
+        return_fig = False):
         '''
         Function to produce a scatter plot of adhesion vs. modulus values for a single
         experiment
@@ -1294,6 +1359,9 @@ class AFM:
                 yaxis_title_text='Modulus (MPa)'
             )
         fig.show()
+            
+        if return_fig == True:
+            return fig
 
     def force_map(self,
         x_cells = 10,
@@ -1406,6 +1474,8 @@ class AFM:
             x_pos = x_pos * x_scale/x_cells
             y_pos = y_pos * y_scale/y_cells
 
+            self.contact_point = self.contact_point[0]
+
             if plot == 'adhesion':
                 plt_title = 'Adhesion (nN)'
                 plt_data = adhesion
